# Gravitational utilities in Python
The `gravtools` module is a complementary module to the existing, well-written libraries
[pycbc]() and [gwpy](). This package began as a few simple utilities, such as constants
and date conversion helper functions.

[![Build Status](https://travis-ci.com/JWKennington/gravtools.svg?branch=master)](https://travis-ci.com/JWKennington/gravtools) 
